# Reset_feedback

*Tip: This plug-in has the same effect as presenting a FEEDBACK item with a duration of 0 ms.*

If you do not reset feedback variables, you may confound your feedback with responses that are not relevant to the task. For example, the key presses made during the instruction phase may affect the feedback during
the first block of the experiment. Therefore, you will need to reset the feedback variables at appropriate moments.

This plug-in will reset the following variables to 0:

- `total_response_time`
- `total_response`
- `acc`
- `accuracy`
- `avg_rt`
- `average_response_time`

For more information, see:

- <http://osdoc.cogsci.nl/3.2/manual/stimuli/visual/>
